## Pipeline

::: ceruleo.transformation.functional.pipeline.pipeline

## Cache

::: ceruleo.transformation.functional.pipeline.cache_store

## Cache

::: ceruleo.transformation.functional.pipeline.runner


## Traversal

::: ceruleo.transformation.functional.pipeline.traversal


## Utils

::: ceruleo.transformation.functional.pipeline.utils
